Attribute VB_Name = "NewHoleDefinition"
'--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
'-------------------------------------------------NewHoleDefinition------------------------------------------------------------------------------------------------------
'Author:    Daniel Frauenrath
'Mail:      daniel.frauenrath@gmx.com
'Release:   08.04.2009
'Version:   1.1
'
'*************************************************************************************************************************************************************************
'<<<<<<<<<<<<<<<<Beschreibung / Discription>>>>>>>>>>>>>>>>>>>>
'**************************************************************************************************************************************************************************
'
'DE: Das Makro ndert die Bohrtabellen aller Bohrungen mit Gewinde auf eine neue vom Anwender bestimmt Gewindetabelle
'
'\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\
'
'EN: The macro changes the hole tables of all threaded holes. The user needs to select the new table before
'
'*************************************************************************************************************************************************************************
'<<<<<<<<<<<<<<<<Vernderungen / Change log>>>>>>>>>>>>>>>>>>>>
'**************************************************************************************************************************************************************************
'Autor:                 Datum:          Zeile/Line:     Modul / UserForm:       Anmerkung/Remark:
'--------------------------------------------------------------------------------------------------------------------------
'Daniel Frauenrath      08.04.2009      82              NewHoleDefinition       Filter der Dialogbox gendert
'Daniel Frauenrath      08.04.2009      93 ff.          NewHoleDefinition       Neu Splitfilter wg. Filternderung
'
'
'****************************************************************************************************************************************************
'<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<Hauptmakro>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>
'****************************************************************************************************************************************************
Sub CATMain()

'**********************************Abfrage Dokumente**********************************
    Dim oFenster As Windows
    Dim oDoc As Document
    Dim ObjType As String
    Set oFenster = CATIA.Windows
    If oFenster.Count = 0 Then
        Box = MsgBox("Es ist kein Dokument geladen!" + Chr(10) + "Das Makro kann nicht ausgefhrt werden und wird beendet!", vbCritical, "Keine Dokument geladen")
        Exit Sub
    End If
    Set oDoc = CATIA.ActiveDocument
    ObjType = TypeName(oDoc)
    If ObjType <> "PartDocument" Then
        Box = MsgBox("Das aktive Dokument ist kein CATPart!" + Chr(10) + "Das Makro kann nicht ausgefhrt werden!", _
                vbCritical + vbOKOnly, "Falscher Dateityp")
        Exit Sub
    End If
    
'**********************************Gewinde suchen**********************************
    Dim oSel As Selection
    Dim allHoles()
    Dim ThreadCounter As Integer
    ThreadCounter = -1
    Set oSel = oDoc.Selection
    oSel.Search "CATPrtSearch.Hole,all"
    If oSel.Count = 0 Then
        Box = MsgBox("Es wurden keine Bohrungen im Part gefunden!" + Chr(10) + _
                    "Das Makro wird beendet!", vbExclamation + vbOKOnly, "Keine Bohrungen gefunden")
        Exit Sub
    Else
        For j = 1 To oSel.Count
            Set myThreadHole = oSel.Item(j).Value
            ThreadCheck = myThreadHole.ThreadingMode
            If ThreadCheck = 0 Then 'Das Loch besitzt ein Gewinde
                ThreadCounter = ThreadCounter + 1
                ReDim Preserve allHoles(ThreadCounter)
                Set allHoles(ThreadCounter) = myThreadHole
            End If
        Next
    End If
    oSel.Clear
    If ThreadCounter = -1 Then
        Box = MsgBox("Die gefundenen Bohrungen besitzen keine Gewindedefinition!" + Chr(10) + _
                    "Das Makro kann nicht ausgefhrt werden und wird beendet", vbExclamation + vbOKOnly, "Keine Gewindedefinitionen")
        Exit Sub
    End If
    
'**********************************Neue Bohrtabelle auswhlen**********************************
    Dim myNewTableFileNameRaw, OpenDialog, FilterTyp As String
    Set OpenDialog = CreateObject("MSComDlg.CommonDialog")
    OpenDialog.DialogTitle = "Bohrtabelle auswhlen"
    OpenDialog.Filter = "Textdateien-Datei (*.txt)|*.txt|Exceldateien (*.xls) | *.xls"
    OpenDialog.DefaultExt = ".txt"
    OpenDialog.flags = &H1814
    OpenDialog.ShowOpen
    myNewTableFileNameRaw = OpenDialog.Filename
    If myNewTableFileNameRaw = "" Then
        Box = MsgBox("Sie haben die Auswahl der neuen Bohrtabelle abgebrochen!" + Chr(10) + _
                    "Das Makro wird beendet!", vbExclamation + vbOKOnly, "Abbruch der Auswahl")
        Exit Sub
        Set OpenDialog = Nothing
    End If
    If OpenDialog.FilterIndex = 1 Then
        FilterType = ".txt"
    ElseIf OpenDialog.FilterIndex = 2 Then
        FilterType = ".xls"
    End If
    Set OpenDialog = Nothing
    
'**********************************Neuen Namen auslesen**********************************
    Dim myNewTableFileName() As String
    Dim myNewName() As String
    myNewNameRaw = Split(myNewTableFileNameRaw, "\")
    myNewNameSEMI = Split(myNewNameRaw(UBound(myNewNameRaw)), FilterType)
    myNewNameToCheck = myNewNameSEMI(0)
    For ii = 0 To UBound(allHoles)
        ReDim Preserve myNewTableFileName(UBound(allHoles))
        ReDim Preserve myNewName(UBound(allHoles))
        myNewName(ii) = myNewNameToCheck
        myNewTableFileName(ii) = myNewTableFileNameRaw
    Next

'**********************************Neue Bohrtabelle setzen**********************************
    For i = 0 To UBound(allHoles)
        Set myHole = allHoles(i)
        myOldThreadDes = myHole.HoleThreadDescription.Value
        myNewThreadDes = Replace(myOldThreadDes, ",", ".")
        myHole.CreateUserStandardDesignTable myNewName(i), myNewTableFileName(i)
        myHole.HoleThreadDescription.Value = myNewThreadDes
        Bohrungscounter = Bohrungscounter + 1
    Next
    
'**********************************Part updaten u. Makro beenden**********************************
    oDoc.Part.Update
    oSel.Clear
    Box = MsgBox("Es wurden " & Bohrungscounter & " Bohrungen aktualisiert!" + Chr(10) + _
                "Der neue Bohrungstyp laut: " & myNewNameSEMI(0), vbInformation + vbOKOnly, "Makro erfolgreich beendet")
End Sub
